#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from openeye import oechem
import sys

if len(sys.argv) != 2:
    oechem.OEThrow.Usage("%s <pdbfile>" % sys.argv[0])

ifs = oechem.oemolistream()
if not ifs.open(sys.argv[1]):
    oechem.OEThrow.Fatal("Unable to open %s" % sys.argv[1])

# need to set input flavor to ensure PDB data is stored on molecule
ifs.SetFlavor(oechem.OEFormat_PDB, (oechem.OEIFlavor_Generic_Default |
                                    oechem.OEIFlavor_PDB_Default |
                                    oechem.OEIFlavor_PDB_DATA))

mol = oechem.OEGraphMol()
while oechem.OEReadMolecule(ifs, mol):
    if oechem.OEHasPDBData(mol, "COMPND"):
        print("COMPND:")
        print(oechem.OEGetPDBData(mol, "COMPND"))

    if oechem.OEHasPDBData(mol, "HELIX "):
        print("HELIX:")
        print(oechem.OEGetPDBData(mol, "HELIX "))

    if oechem.OEHasPDBData(mol, "SSBOND"):
        print("SSBOND:")
        for dp in oechem.OEGetPDBDataPairs(mol):
            if dp.GetTag() == "SSBOND":
                print(dp.GetValue())
# @ </SNIPPET>
